@@ -37,7 +37,10 @@ struct _GthChangeDateTaskPrivate {
 };
 
 
-G_DEFINE_TYPE (GthChangeDateTask, gth_change_date_task, GTH_TYPE_TASK)
+G_DEFINE_TYPE_WITH_CODE (GthChangeDateTask,
+			 gth_change_date_task,
+			 GTH_TYPE_TASK,
+			 G_ADD_PRIVATE (GthChangeDateTask))
 
 
 static void
@@ -251,14 +254,6 @@ set_date_time_from_field (GthChangeDateTask *self,
 		if ((m != NULL) && _g_time_val_from_exif_date (gth_metadata_get_raw (m), &time_val))
 			gth_datetime_from_timeval (date_time, &time_val);
 	}
-	else if (field & GTH_CHANGE_EXIF_DATETIMEORIGINAL_TAG) {
-		GthMetadata *m;
-		GTimeVal     time_val;
-
-		m = (GthMetadata *) g_file_info_get_attribute_object (file_data->info, "Exif::Photo::DateTimeOriginal");
-		if ((m != NULL) && _g_time_val_from_exif_date (gth_metadata_get_raw (m), &time_val))
-			gth_datetime_from_timeval (date_time, &time_val);
-	}
 }
 
 
@@ -294,12 +289,6 @@ info_ready_cb (GList    *files,
 				if (gth_datetime_valid (date_time))
 					set_date_metadata (file_data, "general::datetime", date_time, self->priv->time_offset);
 			}
-			if (self->priv->fields & GTH_CHANGE_EXIF_DATETIMEORIGINAL_TAG) {
-				gth_datetime_clear (date_time);
-				set_date_time_from_field (self, date_time, GTH_CHANGE_EXIF_DATETIMEORIGINAL_TAG, file_data);
-				if (gth_datetime_valid (date_time))
-					set_date_metadata (file_data, "Exif::Photo::DateTimeOriginal", date_time, self->priv->time_offset);
-			}
 		}
 		else {
 			gth_datetime_clear (date_time);
@@ -308,9 +297,6 @@ info_ready_cb (GList    *files,
 				if (self->priv->fields & GTH_CHANGE_COMMENT_DATE) {
 					set_date_metadata (file_data, "general::datetime", date_time, 0);
 				}
-				if (self->priv->fields & GTH_CHANGE_EXIF_DATETIMEORIGINAL_TAG) {
-					set_date_metadata (file_data, "Exif::Photo::DateTimeOriginal", date_time, 0);
-				}
 			}
 		}
 	}
@@ -318,14 +304,12 @@ info_ready_cb (GList    *files,
 	attribute_v = g_ptr_array_new ();
 	if (self->priv->fields & GTH_CHANGE_COMMENT_DATE)
 		g_ptr_array_add (attribute_v, "general::datetime");
-	if (self->priv->fields & GTH_CHANGE_EXIF_DATETIMEORIGINAL_TAG)
-		g_ptr_array_add (attribute_v, "Exif::Photo::DateTimeOriginal");
 	if (attribute_v->len > 0) {
 		char *attributes;
 
 		attributes = _g_string_array_join (attribute_v, ",");
 		_g_write_metadata_async (self->priv->file_list,
-					 (self->priv->fields & GTH_CHANGE_EXIF_DATETIMEORIGINAL_TAG) ? GTH_METADATA_WRITE_FORCE_EMBEDDED : GTH_METADATA_WRITE_DEFAULT,
+					 GTH_METADATA_WRITE_DEFAULT,
 					 attributes,
 					 gth_task_get_cancellable (GTH_TASK (self)),
 					 write_metadata_ready_cb,
@@ -361,8 +345,6 @@ gth_change_date_task_class_init (GthChangeDateTaskClass *klass)
 	GObjectClass *object_class;
 	GthTaskClass *task_class;
 
-	g_type_class_add_private (klass, sizeof (GthChangeDateTaskPrivate));
-
 	object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = gth_change_date_task_finalize;
 
@@ -374,7 +356,7 @@ gth_change_date_task_class_init (GthChangeDateTaskClass *klass)
 static void
 gth_change_date_task_init (GthChangeDateTask *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_CHANGE_DATE_TASK, GthChangeDateTaskPrivate);
+	self->priv = gth_change_date_task_get_instance_private (self);
 	self->priv->date_time = gth_datetime_new ();
 }
 
