@@ -51,8 +51,8 @@ typedef struct {
 	int                  max_resolution;
 	FacebookVisibility   visibility_level;
 	GCancellable        *cancellable;
-        GAsyncReadyCallback  callback;
-        gpointer             user_data;
+	GAsyncReadyCallback  callback;
+	gpointer             user_data;
 	GList               *current;
 	goffset              total_size;
 	goffset              uploaded_size;
@@ -78,9 +78,6 @@ post_photos_data_free (PostPhotosData *post_photos)
 /* -- facebook_service -- */
 
 
-G_DEFINE_TYPE (FacebookService, facebook_service, WEB_TYPE_SERVICE)
-
-
 struct _FacebookServicePrivate {
 	char           *state;
 	char           *token;
@@ -88,6 +85,12 @@ struct _FacebookServicePrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (FacebookService,
+			 facebook_service,
+			 WEB_TYPE_SERVICE,
+			 G_ADD_PRIVATE (FacebookService))
+
+
 static void
 facebook_service_finalize (GObject *object)
 {
@@ -336,12 +339,12 @@ facebook_service_get_user_info_ready_cb (SoupSession *session,
 				         SoupMessage *msg,
 				         gpointer     user_data)
 {
-	FacebookService    *self = user_data;
-	GSimpleAsyncResult *result;
-	GError             *error = NULL;
-	JsonNode           *node;
+	FacebookService *self = user_data;
+	GTask           *task;
+	GError          *error = NULL;
+	JsonNode        *node;
 
-	result = _web_service_get_result (WEB_SERVICE (self));
+	task = _web_service_get_task (WEB_SERVICE (self));
 
 	if (facebook_utils_parse_response (msg, &node, &error)) {
 		OAuthAccount *account;
@@ -351,17 +354,13 @@ facebook_service_get_user_info_ready_cb (SoupSession *session,
 			      "token", _facebook_service_get_access_token (self),
 			      "token-secret", _facebook_service_get_access_token (self),
 			      NULL);
-		g_simple_async_result_set_op_res_gpointer (result,
-							   g_object_ref (account),
-							   (GDestroyNotify) g_object_unref);
+		g_task_return_pointer (task, g_object_ref (account), (GDestroyNotify) g_object_unref);
 
 		_g_object_unref (account);
 		json_node_free (node);
 	}
 	else
-		g_simple_async_result_set_from_error (result, error);
-
-	g_simple_async_result_complete_in_idle (result);
+		g_task_return_error (task, error);
 }
 
 
@@ -402,8 +401,6 @@ facebook_service_class_init (FacebookServiceClass *klass)
 	GObjectClass    *object_class;
 	WebServiceClass *service_class;
 
-	g_type_class_add_private (klass, sizeof (FacebookServicePrivate));
-
 	object_class = (GObjectClass*) klass;
 	object_class->finalize = facebook_service_finalize;
 
@@ -416,7 +413,7 @@ facebook_service_class_init (FacebookServiceClass *klass)
 static void
 facebook_service_init (FacebookService *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, FACEBOOK_TYPE_SERVICE, FacebookServicePrivate);
+	self->priv = facebook_service_get_instance_private (self);
 	self->priv->state = NULL;
 	self->priv->token = NULL;
 	self->priv->post_photos = NULL;
@@ -448,11 +445,11 @@ facebook_service_get_albums_ready_cb (SoupSession *session,
 				      gpointer     user_data)
 {
 	FacebookService    *self = user_data;
-	GSimpleAsyncResult *result;
+	GTask              *task;
 	JsonNode           *node;
 	GError             *error = NULL;
 
-	result = _web_service_get_result (WEB_SERVICE (self));
+	task = _web_service_get_task (WEB_SERVICE (self));
 
 	if (facebook_utils_parse_response (msg, &node, &error)) {
 		GList      *albums = NULL;
@@ -472,14 +469,12 @@ facebook_service_get_albums_ready_cb (SoupSession *session,
 		}
 
 		albums = g_list_reverse (albums);
-		g_simple_async_result_set_op_res_gpointer (result, albums, (GDestroyNotify) _g_object_list_unref);
+		g_task_return_pointer (task, albums, (GDestroyNotify) _g_object_list_unref);
 
 		json_node_free (node);
 	}
 	else
-		g_simple_async_result_set_from_error (result, error);
-
-	g_simple_async_result_complete_in_idle (result);
+		g_task_return_error (task, error);
 }
 
 
@@ -526,10 +521,7 @@ facebook_service_get_albums_finish (FacebookService  *service,
 				    GAsyncResult     *result,
 				    GError          **error)
 {
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
-		return NULL;
-	else
-		return _g_object_list_ref (g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result)));
+	return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 
@@ -572,11 +564,11 @@ facebook_service_create_album_ready_cb (SoupSession *session,
 {
 	CreateAlbumData    *ca_data = user_data;
 	FacebookService    *self = ca_data->service;
-	GSimpleAsyncResult *result;
+	GTask              *task;
 	JsonNode           *node;
 	GError             *error = NULL;
 
-	result = _web_service_get_result (WEB_SERVICE (self));
+	task = _web_service_get_task (WEB_SERVICE (self));
 
 	if (facebook_utils_parse_response (msg, &node, &error)) {
 		FacebookAlbum *album;
@@ -587,14 +579,12 @@ facebook_service_create_album_ready_cb (SoupSession *session,
 		obj = json_node_get_object (node);
 		id = json_object_get_string_member (obj, "id");
 		g_object_set (album, "id", id, NULL);
-		g_simple_async_result_set_op_res_gpointer (result, album, (GDestroyNotify) _g_object_unref);
+		g_task_return_pointer (task, album, (GDestroyNotify) _g_object_unref);
 
 		json_node_free (node);
 	}
 	else
-		g_simple_async_result_set_from_error (result, error);
-
-	g_simple_async_result_complete_in_idle (result);
+		g_task_return_error (task, error);
 
 	create_album_data_free (ca_data);
 }
@@ -654,10 +644,7 @@ facebook_service_create_album_finish (FacebookService  *self,
 				      GAsyncResult     *result,
 				      GError          **error)
 {
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
-		return NULL;
-	else
-		return g_object_ref (g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result)));
+	return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 
@@ -668,12 +655,12 @@ static void
 upload_photos_done (FacebookService *self,
 		    GError          *error)
 {
-	GSimpleAsyncResult *result;
+	GTask *task;
 
-	result = _web_service_get_result (WEB_SERVICE (self));
+	task = _web_service_get_task (WEB_SERVICE (self));
 	if (error == NULL) {
 		self->priv->post_photos->ids = g_list_reverse (self->priv->post_photos->ids);
-		g_simple_async_result_set_op_res_gpointer (result, self->priv->post_photos->ids, (GDestroyNotify) _g_string_list_free);
+		g_task_return_pointer (task, self->priv->post_photos->ids, (GDestroyNotify) _g_string_list_free);
 		self->priv->post_photos->ids = NULL;
 	}
 	else {
@@ -685,10 +672,8 @@ upload_photos_done (FacebookService *self,
 			g_free (error->message);
 			error->message = msg;
 		}
-		g_simple_async_result_set_from_error (result, error);
+		g_task_return_error (task, error);
 	}
-
-	g_simple_async_result_complete_in_idle (result);
 }
 
 
@@ -990,10 +975,7 @@ facebook_service_upload_photos_finish (FacebookService  *self,
 				       GAsyncResult     *result,
 				       GError          **error)
 {
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
-		return NULL;
-	else
-		return _g_string_list_dup (g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result)));
+	return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 
@@ -1006,11 +988,11 @@ facebook_service_list_photos_ready_cb (SoupSession *session,
 				       gpointer     user_data)
 {
 	FacebookService    *self = user_data;
-	GSimpleAsyncResult *result;
+	GTask              *task;
 	JsonNode           *node;
 	GError             *error = NULL;
 
-	result = _web_service_get_result (WEB_SERVICE (self));
+	task = _web_service_get_task (WEB_SERVICE (self));
 
 	if (facebook_utils_parse_response (msg, &node, &error)) {
 		GList      *photos = NULL;
@@ -1033,14 +1015,12 @@ facebook_service_list_photos_ready_cb (SoupSession *session,
 		}
 
 		photos = g_list_reverse (photos);
-		g_simple_async_result_set_op_res_gpointer (result, photos, (GDestroyNotify) _g_object_list_unref);
+		g_task_return_pointer (task, photos, (GDestroyNotify) _g_object_list_unref);
 
 		json_node_free (node);
 	}
 	else
-		g_simple_async_result_set_from_error (result, error);
-
-	g_simple_async_result_complete_in_idle (result);
+		g_task_return_error (task, error);
 }
 
 
@@ -1096,8 +1076,5 @@ facebook_service_list_photos_finish (FacebookService  *self,
 				   GAsyncResult   *result,
 				   GError        **error)
 {
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
-		return NULL;
-	else
-		return _g_object_list_ref (g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result)));
+	return g_task_propagate_pointer (G_TASK (result), error);
 }
