@@ -19,8 +19,8 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GDK_PIXBUF_BLUR_H
-#define GDK_PIXBUF_BLUR_H
+#ifndef CAIRO_BLUR_H
+#define CAIRO_BLUR_H
 
 #include <glib.h>
 #include <cairo.h>
@@ -39,4 +39,4 @@ gboolean _cairo_image_surface_sharpen  (cairo_surface_t *source,
 
 G_END_DECLS
 
-#endif /* GDK_PIXBUF_BLUR_H */
+#endif /* CAIRO_BLUR_H */
