@@ -22,7 +22,7 @@
 #include <config.h>
 #include <gthumb.h>
 #include <extensions/image_viewer/image-viewer.h>
-#include "enum-types.h"
+#include "file-tools-enum-types.h"
 #include "gth-file-tool-crop.h"
 #include "preferences.h"
 
@@ -30,9 +30,6 @@
 #define GET_WIDGET(x) (_gtk_builder_get_widget (self->priv->builder, (x)))
 
 
-G_DEFINE_TYPE (GthFileToolCrop, gth_file_tool_crop, GTH_TYPE_IMAGE_VIEWER_PAGE_TOOL)
-
-
 struct _GthFileToolCropPrivate {
 	GSettings        *settings;
 	GtkBuilder       *builder;
@@ -50,6 +47,12 @@ struct _GthFileToolCropPrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (GthFileToolCrop,
+			 gth_file_tool_crop,
+			 GTH_TYPE_IMAGE_VIEWER_PAGE_TOOL,
+			 G_ADD_PRIVATE (GthFileToolCrop))
+
+
 static gpointer
 crop_exec (GthAsyncTask *task,
 	   gpointer      user_data)
@@ -422,6 +425,8 @@ gth_file_tool_crop_get_options (GthFileTool *base)
 	gth_image_viewer_get_original_size (GTH_IMAGE_VIEWER (viewer), &self->priv->original_width, &self->priv->original_height);
 	_gtk_widget_get_screen_size (window, &self->priv->screen_width, &self->priv->screen_height);
 
+	if (self->priv->settings == NULL)
+		self->priv->settings = g_settings_new (GTHUMB_CROP_SCHEMA);
 	self->priv->builder = _gtk_builder_new_from_file ("crop-options.ui", "file_tools");
 
 	options = _gtk_builder_get_widget (self->priv->builder, "options");
@@ -677,8 +682,8 @@ gth_file_tool_crop_reset_image (GthImageViewerPageTool *base)
 static void
 gth_file_tool_crop_init (GthFileToolCrop *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_FILE_TOOL_CROP, GthFileToolCropPrivate);
-	self->priv->settings = g_settings_new (GTHUMB_CROP_SCHEMA);
+	self->priv = gth_file_tool_crop_get_instance_private (self);
+	self->priv->settings = NULL;
 	gth_file_tool_construct (GTH_FILE_TOOL (self), "image-crop-symbolic", _("Crop"), GTH_TOOLBOX_SECTION_FORMAT);
 }
 
@@ -709,8 +714,6 @@ gth_file_tool_crop_class_init (GthFileToolCropClass *klass)
 	GthFileToolClass            *file_tool_class;
 	GthImageViewerPageToolClass *image_viewer_page_tool_class;
 
-	g_type_class_add_private (klass, sizeof (GthFileToolCropPrivate));
-
 	gobject_class = (GObjectClass*) klass;
 	gobject_class->finalize = gth_file_tool_crop_finalize;
 
