@@ -35,9 +35,6 @@
 #define PREVIEW_SIZE 0.9
 
 
-G_DEFINE_TYPE (GthFileToolCurves, gth_file_tool_curves, GTH_TYPE_IMAGE_VIEWER_PAGE_TOOL)
-
-
 struct _GthFileToolCurvesPrivate {
 	cairo_surface_t    *destination;
 	cairo_surface_t    *preview;
@@ -62,6 +59,12 @@ struct _GthFileToolCurvesPrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (GthFileToolCurves,
+			 gth_file_tool_curves,
+			 GTH_TYPE_IMAGE_VIEWER_PAGE_TOOL,
+			 G_ADD_PRIVATE (GthFileToolCurves))
+
+
 /* -- apply_changes -- */
 
 
@@ -844,7 +847,7 @@ gth_file_tool_curves_populate_headerbar (GthFileTool *base,
 							   _("Presets"),
 							   NULL,
 							   NULL);
-	gtk_widget_set_margin_left (button, GTH_BROWSER_HEADER_BAR_BIG_MARGIN);
+	gtk_widget_set_margin_start (button, GTH_BROWSER_HEADER_BAR_BIG_MARGIN);
 	self->priv->show_presets_button = button;
 	g_signal_connect (button,
 			  "toggled",
@@ -877,7 +880,7 @@ gth_file_tool_sharpen_reset_image (GthImageViewerPageTool *base)
 static void
 gth_file_tool_curves_init (GthFileToolCurves *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_FILE_TOOL_CURVES, GthFileToolCurvesPrivate);
+	self->priv = gth_file_tool_curves_get_instance_private (self);
 	self->priv->preview = NULL;
 	self->priv->destination = NULL;
 	self->priv->builder = NULL;
@@ -917,8 +920,6 @@ gth_file_tool_curves_class_init (GthFileToolCurvesClass *klass)
 	GthFileToolClass            *file_tool_class;
 	GthImageViewerPageToolClass *image_viewer_page_tool_class;
 
-	g_type_class_add_private (klass, sizeof (GthFileToolCurvesPrivate));
-
 	gobject_class = (GObjectClass*) klass;
 	gobject_class->finalize = gth_file_tool_curves_finalize;
 
