@@ -33,9 +33,6 @@
 #define PIXELS_UNIT_POSITION 0
 
 
-G_DEFINE_TYPE (GthFileToolResize, gth_file_tool_resize, GTH_TYPE_IMAGE_VIEWER_PAGE_TOOL)
-
-
 struct _GthFileToolResizePrivate {
 	GSettings       *settings;
 	cairo_surface_t *preview;
@@ -59,6 +56,12 @@ struct _GthFileToolResizePrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (GthFileToolResize,
+			 gth_file_tool_resize,
+			 GTH_TYPE_IMAGE_VIEWER_PAGE_TOOL,
+			 G_ADD_PRIVATE (GthFileToolResize))
+
+
 static void update_image_size (GthFileToolResize *self);
 
 
@@ -527,6 +530,9 @@ gth_file_tool_resize_get_options (GthFileTool *base)
 	if (source == NULL)
 		return NULL;
 
+	if (self->priv->settings == NULL)
+		self->priv->settings = g_settings_new (GTHUMB_RESIZE_SCHEMA);
+
 	self->priv->original_width = cairo_image_surface_get_width (source);
 	self->priv->original_height = cairo_image_surface_get_height (source);
 
@@ -807,8 +813,6 @@ gth_file_tool_resize_class_init (GthFileToolResizeClass *klass)
 	GthFileToolClass            *file_tool_class;
 	GthImageViewerPageToolClass *image_viewer_page_tool_class;
 
-	g_type_class_add_private (klass, sizeof (GthFileToolResizePrivate));
-
 	gobject_class = (GObjectClass*) klass;
 	gobject_class->finalize = gth_file_tool_resize_finalize;
 
@@ -826,8 +830,8 @@ gth_file_tool_resize_class_init (GthFileToolResizeClass *klass)
 static void
 gth_file_tool_resize_init (GthFileToolResize *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_FILE_TOOL_RESIZE, GthFileToolResizePrivate);
-	self->priv->settings = g_settings_new (GTHUMB_RESIZE_SCHEMA);
+	self->priv = gth_file_tool_resize_get_instance_private (self);
+	self->priv->settings = NULL;
 	self->priv->builder = NULL;
 	self->priv->preview = NULL;
 	self->priv->new_image = NULL;
