@@ -37,13 +37,6 @@
 static void gth_viewer_page_interface_init (GthViewerPageInterface *iface);
 
 
-G_DEFINE_TYPE_WITH_CODE (GthMediaViewerPage,
-			 gth_media_viewer_page,
-			 G_TYPE_OBJECT,
-			 G_IMPLEMENT_INTERFACE (GTH_TYPE_VIEWER_PAGE,
-					 	gth_viewer_page_interface_init))
-
-
 struct _GthMediaViewerPagePrivate {
 	GthBrowser     *browser;
 	GthFileData    *file_data;
@@ -79,6 +72,14 @@ struct _GthMediaViewerPagePrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (GthMediaViewerPage,
+			 gth_media_viewer_page,
+			 G_TYPE_OBJECT,
+			 G_ADD_PRIVATE (GthMediaViewerPage)
+			 G_IMPLEMENT_INTERFACE (GTH_TYPE_VIEWER_PAGE,
+						gth_viewer_page_interface_init))
+
+
 static double default_rates[] = { 0.03, 0.06, 0.12, 0.25, 0.33, 0.50, 0.66, 1.0, 1.50, 2.0, 3.0, 4.0, 8.0, 16.0, 32.0 };
 
 
@@ -127,8 +128,8 @@ video_area_realize_cb (GtkWidget *widget,
 {
 	GthMediaViewerPage *self = user_data;
 
-	self->priv->cursor = gdk_cursor_new (GDK_LEFT_PTR);
-	self->priv->cursor_void = gdk_cursor_new_for_display (gtk_widget_get_display (self->priv->video_area), GDK_BLANK_CURSOR);
+	self->priv->cursor = _gdk_cursor_new_for_widget (widget, GDK_LEFT_PTR);
+	self->priv->cursor_void = _gdk_cursor_new_for_widget (self->priv->video_area, GDK_BLANK_CURSOR);
 
 	if (self->priv->cursor_visible)
 		gdk_window_set_cursor (gtk_widget_get_window (self->priv->video_area), self->priv->cursor);
@@ -806,8 +807,31 @@ create_playbin (GthMediaViewerPage *self)
 		return;
 
 	self->priv->playbin = gst_element_factory_make ("playbin", "playbin");
-	video_sink = gst_element_factory_make ("gtksink", NULL);
-	g_object_set (self->priv->playbin, "video-sink", video_sink, NULL);
+
+	settings = g_settings_new (GTHUMB_GSTREAMER_TOOLS_SCHEMA);
+	if (g_settings_get_boolean (settings, PREF_GSTREAMER_USE_HARDWARE_ACCEL)) {
+		GstElement *video_bin;
+		GstElement *glupload;
+		GstPad     *pad;
+		GstPad     *ghost_pad;
+
+		/* pipeline taken from GNOME Twitch */
+
+		video_sink = gst_element_factory_make ("gtkglsink", "sink");
+		video_bin = gst_bin_new ("video_bin");
+		glupload = gst_element_factory_make ("glupload", NULL);
+		gst_bin_add_many (GST_BIN(video_bin), glupload, video_sink, NULL);
+		gst_element_link_many (glupload, video_sink, NULL);
+		pad = gst_element_get_static_pad (glupload, "sink");
+		ghost_pad = gst_ghost_pad_new ("sink", pad);
+		gst_pad_set_active (ghost_pad, TRUE);
+		gst_element_add_pad (video_bin, ghost_pad);
+		g_object_set (self->priv->playbin, "video-sink", video_bin, NULL);
+	}
+	else {
+		video_sink = gst_element_factory_make ("gtksink", "sink");
+		g_object_set (self->priv->playbin, "video-sink", video_sink, NULL);
+	}
 
 	g_object_get (video_sink, "widget", &self->priv->video_area, NULL);
 	gtk_style_context_add_class (gtk_widget_get_style_context (self->priv->video_area), "video-player");
@@ -847,7 +871,6 @@ create_playbin (GthMediaViewerPage *self)
 	gtk_stack_add_named (GTK_STACK (self->priv->area_box), self->priv->video_area, "video-area");
 	gtk_widget_show (self->priv->video_area);
 
-	settings = g_settings_new (GTHUMB_GSTREAMER_TOOLS_SCHEMA);
 	g_object_set (self->priv->playbin,
 		      "volume", (double) g_settings_get_int (settings, PREF_GSTREAMER_TOOLS_VOLUME) / 100.0,
 		      "force-aspect-ratio", TRUE,
@@ -1310,8 +1333,6 @@ gth_media_viewer_page_finalize (GObject *obj)
 static void
 gth_media_viewer_page_class_init (GthMediaViewerPageClass *klass)
 {
-	g_type_class_add_private (klass, sizeof (GthMediaViewerPagePrivate));
-
 	G_OBJECT_CLASS (klass)->finalize = gth_media_viewer_page_finalize;
 }
 
@@ -1340,7 +1361,7 @@ gth_viewer_page_interface_init (GthViewerPageInterface *iface)
 static void
 gth_media_viewer_page_init (GthMediaViewerPage *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_MEDIA_VIEWER_PAGE, GthMediaViewerPagePrivate);
+	self->priv = gth_media_viewer_page_get_instance_private (self);
 	self->priv->update_progress_id = 0;
 	self->priv->update_volume_id = 0;
 	self->priv->has_video = FALSE;
