@@ -31,63 +31,72 @@
 #define MIN_HISTOGRAM_HEIGHT 280
 
 
-static void gth_image_histogram_gth_multipage_child_interface_init (GthMultipageChildInterface *iface);
 static void gth_image_histogram_gth_property_view_interface_init (GthPropertyViewInterface *iface);
 
 
-G_DEFINE_TYPE_WITH_CODE (GthImageHistogram,
-			 gth_image_histogram,
-			 GTK_TYPE_BOX,
-			 G_IMPLEMENT_INTERFACE (GTH_TYPE_MULTIPAGE_CHILD,
-					        gth_image_histogram_gth_multipage_child_interface_init)
-		         G_IMPLEMENT_INTERFACE (GTH_TYPE_PROPERTY_VIEW,
-		        		        gth_image_histogram_gth_property_view_interface_init))
-
-
 struct _GthImageHistogramPrivate {
 	GthHistogram *histogram;
 	GtkWidget    *histogram_view;
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (GthImageHistogram,
+			 gth_image_histogram,
+			 GTK_TYPE_BOX,
+			 G_ADD_PRIVATE (GthImageHistogram)
+			 G_IMPLEMENT_INTERFACE (GTH_TYPE_PROPERTY_VIEW,
+						gth_image_histogram_gth_property_view_interface_init))
+
+
+static cairo_surface_t *
+gth_image_histogram_get_current_image (GthImageHistogram *self)
+{
+	GthBrowser    *browser;
+	GthViewerPage *viewer_page;
+
+	browser = (GthBrowser *) gtk_widget_get_toplevel (GTK_WIDGET (self));
+	if (! gtk_widget_is_toplevel (GTK_WIDGET (browser)))
+		return NULL;
+
+	viewer_page = gth_browser_get_viewer_page (browser);
+	if (! GTH_IS_IMAGE_VIEWER_PAGE (viewer_page))
+		return NULL;
+
+	return gth_image_viewer_page_get_current_image (GTH_IMAGE_VIEWER_PAGE (viewer_page));
+}
+
+
+static gboolean
+gth_image_histogram_real_can_view (GthPropertyView *base,
+		 		  GthFileData     *file_data)
+{
+	GthImageHistogram *self = GTH_IMAGE_HISTOGRAM (base);
+	return gth_image_histogram_get_current_image (self) != NULL;
+}
+
+
 static void
 gth_image_histogram_real_set_file (GthPropertyView *base,
 		 		   GthFileData     *file_data)
 {
 	GthImageHistogram *self = GTH_IMAGE_HISTOGRAM (base);
-	GthBrowser        *browser;
-	GthViewerPage     *viewer_page;
+	cairo_surface_t   *image;
 
-	if (file_data == NULL) {
-		gth_histogram_calculate_for_image (self->priv->histogram, NULL);
-		return;
-	}
-
-	browser = (GthBrowser *) gtk_widget_get_toplevel (GTK_WIDGET (base));
-	if (! gtk_widget_is_toplevel (GTK_WIDGET (browser))) {
-		gth_histogram_calculate_for_image (self->priv->histogram, NULL);
-		return;
-	}
-
-	viewer_page = gth_browser_get_viewer_page (browser);
-	if (! GTH_IS_IMAGE_VIEWER_PAGE (viewer_page)) {
-		gth_histogram_calculate_for_image (self->priv->histogram, NULL);
-		return;
-	}
-
-	gth_histogram_calculate_for_image (self->priv->histogram, gth_image_viewer_page_get_current_image (GTH_IMAGE_VIEWER_PAGE (viewer_page)));
+	image = gth_image_histogram_get_current_image (self);
+	if (image != NULL)
+		gth_histogram_calculate_for_image (self->priv->histogram, image);
 }
 
 
 static const char *
-gth_image_histogram_real_get_name (GthMultipageChild *self)
+gth_image_histogram_real_get_name (GthPropertyView *self)
 {
 	return _("Histogram");
 }
 
 
 static const char *
-gth_image_histogram_real_get_icon (GthMultipageChild *self)
+gth_image_histogram_real_get_icon (GthPropertyView *self)
 {
 	return "histogram-symbolic";
 }
@@ -106,22 +115,16 @@ gth_image_histogram_finalize (GObject *base)
 static void
 gth_image_histogram_class_init (GthImageHistogramClass *klass)
 {
-	g_type_class_add_private (klass, sizeof (GthImageHistogramPrivate));
 	G_OBJECT_CLASS (klass)->finalize = gth_image_histogram_finalize;
 }
 
 
-static void
-gth_image_histogram_gth_multipage_child_interface_init (GthMultipageChildInterface *iface)
-{
-	iface->get_name = gth_image_histogram_real_get_name;
-	iface->get_icon = gth_image_histogram_real_get_icon;
-}
-
-
 static void
 gth_image_histogram_gth_property_view_interface_init (GthPropertyViewInterface *iface)
 {
+	iface->get_name = gth_image_histogram_real_get_name;
+	iface->get_icon = gth_image_histogram_real_get_icon;
+	iface->can_view = gth_image_histogram_real_can_view;
 	iface->set_file = gth_image_histogram_real_set_file;
 }
 
@@ -145,12 +148,11 @@ gth_image_histogram_init (GthImageHistogram *self)
 {
 	GSettings *settings;
 
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_IMAGE_HISTOGRAM, GthImageHistogramPrivate);
+	self->priv = gth_image_histogram_get_instance_private (self);
 	self->priv->histogram = gth_histogram_new ();
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_VERTICAL);
 	gtk_box_set_spacing (GTK_BOX (self), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (self), 2);
 
 	settings = g_settings_new (GTHUMB_IMAGE_VIEWER_SCHEMA);
 
