@@ -71,12 +71,14 @@ destroy_dialog (DialogData *data)
 {
 	if (data->dialog != NULL)
 		gtk_widget_destroy (data->dialog);
-	gth_task_completed (GTH_TASK (data->service), NULL);
+	if (data->service != NULL)
+		gth_task_completed (GTH_TASK (data->service), NULL);
 	_g_object_unref (data->cancellable);
 	_g_object_unref (data->album);
 	_g_object_unref (data->service);
 	_g_object_list_unref (data->albums);
-	gtk_widget_destroy (data->progress_dialog);
+	if (data->progress_dialog != NULL)
+		gtk_widget_destroy (data->progress_dialog);
 	_g_object_unref (data->builder);
 	_g_object_list_unref (data->file_list);
 	_g_object_unref (data->location);
@@ -99,37 +101,6 @@ completed_messagedialog_response_cb (GtkDialog *dialog,
 		gtk_dialog_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_DELETE_EVENT);
 		break;
 
-	case _OPEN_IN_BROWSER_RESPONSE:
-		{
-			OAuthAccount *account;
-			GdkScreen    *screen;
-			char         *url = NULL;
-			GError       *error = NULL;
-
-			account = web_service_get_current_account (WEB_SERVICE (data->service));
-			screen = gtk_widget_get_screen (GTK_WIDGET (dialog));
-			gtk_widget_destroy (GTK_WIDGET (dialog));
-
-			if (data->album != NULL) {
-				if (data->album->alternate_url != NULL)
-					url = g_strdup (data->album->alternate_url);
-				else
-					url = g_strconcat ("http://picasaweb.google.com/", account->id, "/", data->album->id, NULL);
-			}
-			else
-				url = g_strconcat ("http://picasaweb.google.com/", account->id, NULL);
-
-			if ((url != NULL) && ! gtk_show_uri (screen, url, 0, &error)) {
-				gth_task_dialog (GTH_TASK (data->service), TRUE, NULL);
-				_gtk_error_dialog_from_gerror_run (GTK_WINDOW (data->browser), _("Could not connect to the server"), error);
-				g_clear_error (&error);
-			}
-			gtk_dialog_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_DELETE_EVENT);
-
-			g_free (url);
-		}
-		break;
-
 	default:
 		break;
 	}
@@ -149,7 +120,6 @@ export_completed_with_success (DialogData *data)
 					  _("Files successfully uploaded to the server."),
 					  NULL,
 					  _GTK_LABEL_CLOSE, GTK_RESPONSE_CLOSE,
-					  _("_Open in the Browser"), _OPEN_IN_BROWSER_RESPONSE,
 					  NULL);
 	g_signal_connect (dialog,
 			  "delete-event",
@@ -295,92 +265,6 @@ update_album_list (DialogData *data)
 }
 
 
-static void
-create_album_ready_cb (GObject      *source_object,
-		       GAsyncResult *result,
-		       gpointer      user_data)
-{
-	DialogData       *data = user_data;
-	PicasaWebService *picasaweb = PICASA_WEB_SERVICE (source_object);
-	PicasaWebAlbum   *album;
-	GError           *error = NULL;
-
-	album = picasa_web_service_create_album_finish (picasaweb, result, &error);
-	if (error != NULL) {
-		gth_task_dialog (GTH_TASK (data->service), TRUE, NULL);
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not create the album"), error);
-		g_clear_error (&error);
-		return;
-	}
-
-	data->albums = g_list_append (data->albums, album);
-	update_album_list (data);
-}
-
-
-static void
-new_album_dialog_response_cb (GtkDialog *dialog,
-			      int        response_id,
-			      gpointer   user_data)
-{
-	DialogData *data = user_data;
-
-	switch (response_id) {
-	case GTK_RESPONSE_DELETE_EVENT:
-	case GTK_RESPONSE_CANCEL:
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-		break;
-
-	case GTK_RESPONSE_OK:
-		{
-			PicasaWebAlbum *album;
-
-			album = picasa_web_album_new ();
-			picasa_web_album_set_title (album, picasa_album_properties_dialog_get_name (PICASA_ALBUM_PROPERTIES_DIALOG (dialog)));
-			album->access = picasa_album_properties_dialog_get_access (PICASA_ALBUM_PROPERTIES_DIALOG (dialog));
-			picasa_web_service_create_album (data->service,
-							 album,
-							 data->cancellable,
-							 create_album_ready_cb,
-							 data);
-
-			g_object_unref (album);
-		}
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-		break;
-
-	default:
-		break;
-	}
-}
-
-
-static void
-add_album_button_clicked_cb (GtkButton *button,
-			     gpointer   user_data)
-{
-	DialogData *data = user_data;
-	GtkWidget  *dialog;
-
-	dialog = picasa_album_properties_dialog_new (g_file_info_get_edit_name (data->location->info),
-						     NULL,
-						     PICASA_WEB_ACCESS_PUBLIC);
-	g_signal_connect (dialog,
-			  "delete-event",
-			  G_CALLBACK (gtk_true),
-			  NULL);
-	g_signal_connect (dialog,
-			  "response",
-			  G_CALLBACK (new_album_dialog_response_cb),
-			  data);
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("New Album"));
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (data->dialog));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	gtk_window_present (GTK_WINDOW (dialog));
-}
-
-
 static void
 edit_accounts_button_clicked_cb (GtkButton *button,
 			         gpointer   user_data)
@@ -607,8 +491,6 @@ dlg_export_to_picasaweb (GthBrowser *browser,
 	if (data->file_list == NULL) {
 		GError *error;
 
-		gth_task_dialog (GTH_TASK (data->service), TRUE, NULL);
-
 		error = g_error_new_literal (GTH_ERROR, GTH_ERROR_GENERIC, _("No valid file selected."));
 		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (browser), _("Could not export the files"), error);
 		g_clear_error (&error);
@@ -655,10 +537,6 @@ dlg_export_to_picasaweb (GthBrowser *browser,
 			  "response",
 			  G_CALLBACK (export_dialog_response_cb),
 			  data);
-	g_signal_connect (GET_WIDGET ("add_album_button"),
-			  "clicked",
-			  G_CALLBACK (add_album_button_clicked_cb),
-			  data);
 	g_signal_connect (GET_WIDGET ("edit_accounts_button"),
 			  "clicked",
 			  G_CALLBACK (edit_accounts_button_clicked_cb),
