@@ -39,9 +39,6 @@
 #define _GST_PLAY_FLAG_AUDIO (1 << 1)
 
 
-G_DEFINE_TYPE (GthSlideshow, gth_slideshow, GTK_TYPE_WINDOW)
-
-
 typedef enum {
 	GTH_SLIDESHOW_DIRECTION_FORWARD,
 	GTH_SLIDESHOW_DIRECTION_BACKWARD
@@ -91,6 +88,12 @@ struct _GthSlideshowPrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (GthSlideshow,
+			 gth_slideshow,
+			 GTK_TYPE_WINDOW,
+			 G_ADD_PRIVATE (GthSlideshow))
+
+
 static void
 _gth_slideshow_close_cb (gpointer user_data)
 {
@@ -192,7 +195,6 @@ _gth_slideshow_load_current_image (GthSlideshow *self)
 	GthFileData *prev_file;
 	int          screen_width;
 	int          screen_height;
-	GdkScreen   *screen;
 
 	if (self->priv->next_event != 0) {
 		g_source_remove (self->priv->next_event);
@@ -217,14 +219,7 @@ _gth_slideshow_load_current_image (GthSlideshow *self)
 	else
 		prev_file = NULL;
 
-	screen_width = -1;
-	screen_height = -1;
-	screen = gtk_widget_get_screen (GTK_WIDGET (self));
-	if (screen != NULL) {
-		screen_width = gdk_screen_get_width (screen);
-		screen_height = gdk_screen_get_height (screen);
-	}
-
+	_gtk_widget_get_screen_size (GTK_WIDGET (self), &screen_width, &screen_height);
 	gth_image_preloader_load (self->priv->preloader,
 				  requested_file,
 				  MAX (screen_width, screen_height),
@@ -339,8 +334,6 @@ gth_slideshow_class_init (GthSlideshowClass *klass)
 {
 	GObjectClass *gobject_class;
 
-	g_type_class_add_private (klass, sizeof (GthSlideshowPrivate));
-
 	gobject_class = G_OBJECT_CLASS (klass);
 	gobject_class->finalize = gth_slideshow_finalize;
 }
@@ -456,7 +449,7 @@ gth_slideshow_show_cb (GtkWidget    *widget,
 static void
 gth_slideshow_init (GthSlideshow *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_SLIDESHOW, GthSlideshowPrivate);
+	self->priv = gth_slideshow_get_instance_private (self);
 	self->priv->file_list = NULL;
 	self->priv->next_event = 0;
 	self->priv->delay = DEFAULT_DELAY;
@@ -716,19 +709,19 @@ default_projector_pause_painter (GthImageViewer *image_viewer,
 				 gpointer        user_data)
 {
 	GthSlideshow *self = user_data;
-	GdkScreen    *screen;
+	int           screen_width;
+	int           screen_height;
 	double        dest_x;
 	double        dest_y;
 
 	if (! self->priv->paused || ! self->priv->paint_paused || (self->priv->pause_pixbuf == NULL))
 		return;
 
-	screen = gtk_widget_get_screen (GTK_WIDGET (image_viewer));
-	if (screen == NULL)
+	if (! _gtk_widget_get_screen_size (GTK_WIDGET (image_viewer), &screen_width, &screen_height))
 		return;
 
-	dest_x = (gdk_screen_get_width (screen) - gdk_pixbuf_get_width (self->priv->pause_pixbuf)) / 2.0;
-	dest_y = (gdk_screen_get_height (screen) - gdk_pixbuf_get_height (self->priv->pause_pixbuf)) / 2.0;
+	dest_x = (screen_width - gdk_pixbuf_get_width (self->priv->pause_pixbuf)) / 2.0;
+	dest_y = (screen_height - gdk_pixbuf_get_height (self->priv->pause_pixbuf)) / 2.0;
 	gdk_cairo_set_source_pixbuf (cr, self->priv->pause_pixbuf, dest_x, dest_y);
 	cairo_rectangle (cr, dest_x, dest_y, gdk_pixbuf_get_width (self->priv->pause_pixbuf), gdk_pixbuf_get_height (self->priv->pause_pixbuf));
 	cairo_fill (cr);
@@ -1069,35 +1062,35 @@ stage_input_cb (ClutterStage *stage,
 	}
 	else if (event->type == CLUTTER_KEY_PRESS) {
 		switch (clutter_event_get_key_symbol (event)) {
-		case CLUTTER_F5:
+		case CLUTTER_KEY_F5:
 			_gth_slideshow_close (self);
 			break;
 		}
 	}
 	else if (event->type == CLUTTER_KEY_RELEASE) {
 		switch (clutter_event_get_key_symbol (event)) {
-		case CLUTTER_Escape:
-		case CLUTTER_q:
+		case CLUTTER_KEY_Escape:
+		case CLUTTER_KEY_q:
 			_gth_slideshow_close (self);
 			break;
-		case CLUTTER_p:
+		case CLUTTER_KEY_p:
 			_gth_slideshow_toggle_pause (self);
 			break;
 
-		case CLUTTER_space:
-		case CLUTTER_Down:
-		case CLUTTER_Right:
-		case CLUTTER_Page_Down:
+		case CLUTTER_KEY_space:
+		case CLUTTER_KEY_Down:
+		case CLUTTER_KEY_Right:
+		case CLUTTER_KEY_Page_Down:
 			if (self->priv->paused)
 				_gth_slideshow_toggle_pause (self);
 			else
 				_gth_slideshow_load_next_image (self);
 			break;
 
-		case CLUTTER_BackSpace:
-		case CLUTTER_Up:
-		case CLUTTER_Left:
-		case CLUTTER_Page_Up:
+		case CLUTTER_KEY_BackSpace:
+		case CLUTTER_KEY_Up:
+		case CLUTTER_KEY_Left:
+		case CLUTTER_KEY_Page_Up:
 			_gth_slideshow_load_prev_image (self);
 			break;
 		}
