@@ -41,9 +41,6 @@
 #define SAVING_TIMEOUT 5
 
 
-G_DEFINE_TYPE (GthWebExporter, gth_web_exporter, GTH_TYPE_TASK)
-
-
 typedef enum {
 	GTH_TEMPLATE_TYPE_INDEX,
 	GTH_TEMPLATE_TYPE_IMAGE,
@@ -165,6 +162,12 @@ struct _GthWebExporterPrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (GthWebExporter,
+			 gth_web_exporter,
+			 GTH_TYPE_TASK,
+			 G_ADD_PRIVATE (GthWebExporter))
+
+
 static LoopInfo *
 loop_info_new (void)
 {
@@ -1776,9 +1779,7 @@ success_dialog_response_cb (GtkDialog *dialog,
 			    gpointer   user_data)
 {
 	GthWebExporter *self = user_data;
-	GdkScreen      *screen;
 
-	screen = gtk_widget_get_screen (GTK_WIDGET (dialog));
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 	switch (response_id) {
@@ -1797,7 +1798,7 @@ success_dialog_response_cb (GtkDialog *dialog,
 				break;
 
 			url = g_file_get_uri (file);
-			if ((url != NULL) && ! gtk_show_uri (screen, url, 0, &error)) {
+			if ((url != NULL) && ! gtk_show_uri_on_window (GTK_WINDOW (self->priv->browser), url, GDK_CURRENT_TIME, &error)) {
 				gth_task_dialog (GTH_TASK (self), TRUE, NULL);
 				_gtk_error_dialog_from_gerror_run (GTK_WINDOW (self->priv->browser), _("Could not show the destination"), error);
 				g_clear_error (&error);
@@ -3143,8 +3144,6 @@ gth_web_exporter_class_init (GthWebExporterClass *klass)
 	GObjectClass *object_class;
 	GthTaskClass *task_class;
 
-	g_type_class_add_private (klass, sizeof (GthWebExporterPrivate));
-
 	object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = gth_web_exporter_finalize;
 
@@ -3157,7 +3156,7 @@ gth_web_exporter_class_init (GthWebExporterClass *klass)
 static void
 gth_web_exporter_init (GthWebExporter *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_WEB_EXPORTER, GthWebExporterPrivate);
+	self->priv = gth_web_exporter_get_instance_private (self);
 	self->priv->header = NULL;
 	self->priv->footer = NULL;
 	self->priv->image_page_header = NULL;
