@@ -150,7 +150,7 @@ gth_application_activate_about (GSimpleAction *action,
 					 NULL);
 
 	gtk_show_about_dialog (GTK_WINDOW (window),
-			       "version", VERSION,
+			       "version", PACKAGE_VERSION,
 			       "copyright", "Copyright \xc2\xa9 2001-2013 Free Software Foundation, Inc.",
 			       "comments", _("An image viewer and browser for GNOME."),
 			       "authors", authors,
@@ -158,7 +158,7 @@ gth_application_activate_about (GSimpleAction *action,
 			       "translator-credits", _("translator-credits"),
 			       "license", license_text,
 			       "wrap-license", TRUE,
-			       "website", "http://live.gnome.org/Apps/gthumb",
+			       "website", "https://wiki.gnome.org/Apps/Gthumb",
 			       (logo != NULL ? "logo" : NULL), logo,
 			       NULL);
 
