@@ -169,7 +169,10 @@ struct _GthExtensionModulePrivate {
 };
 
 
-G_DEFINE_TYPE (GthExtensionModule, gth_extension_module, GTH_TYPE_EXTENSION)
+G_DEFINE_TYPE_WITH_CODE (GthExtensionModule,
+			 gth_extension_module,
+			 GTH_TYPE_EXTENSION,
+			 G_ADD_PRIVATE (GthExtensionModule))
 
 
 static gboolean
@@ -188,7 +191,7 @@ gth_extension_module_real_open (GthExtension  *base,
 	{
 		char *extension_dir;
 
-		extension_dir = g_build_filename (GTHUMB_EXTENSIONS_DIR, self->priv->module_name, ".libs", NULL);
+		extension_dir = g_build_filename (GTHUMB_EXTENSIONS_DIR, self->priv->module_name, NULL);
 		file_name = g_module_build_path (extension_dir, self->priv->module_name);
 		g_free (extension_dir);
 	}
@@ -354,8 +357,6 @@ gth_extension_module_class_init (GthExtensionModuleClass *klass)
 {
 	GthExtensionClass *elc;
 
-	g_type_class_add_private (klass, sizeof (GthExtensionModulePrivate));
-
 	G_OBJECT_CLASS (klass)->finalize = gth_extension_module_finalize;
 
 	elc = GTH_EXTENSION_CLASS (klass);
@@ -371,7 +372,7 @@ gth_extension_module_class_init (GthExtensionModuleClass *klass)
 static void
 gth_extension_module_init (GthExtensionModule *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_EXTENSION_MODULE, GthExtensionModulePrivate);
+	self->priv = gth_extension_module_get_instance_private (self);
 }
 
 
@@ -396,7 +397,10 @@ struct _GthExtensionDescriptionPrivate {
 };
 
 
-G_DEFINE_TYPE (GthExtensionDescription, gth_extension_description, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_CODE (GthExtensionDescription,
+			 gth_extension_description,
+			 G_TYPE_OBJECT,
+			 G_ADD_PRIVATE (GthExtensionDescription))
 
 
 static void
@@ -416,7 +420,6 @@ gth_extension_description_finalize (GObject *obj)
 	g_free (self->url);
 	g_free (self->category);
 	g_free (self->loader_type);
-	g_free (self->loader_file);
 	g_strfreev (self->loader_requires);
 	g_strfreev (self->loader_after);
 	_g_object_unref (self->priv->extension);
@@ -428,7 +431,6 @@ gth_extension_description_finalize (GObject *obj)
 static void
 gth_extension_description_class_init (GthExtensionDescriptionClass *klass)
 {
-	g_type_class_add_private (klass, sizeof (GthExtensionDescriptionPrivate));
 	G_OBJECT_CLASS (klass)->finalize = gth_extension_description_finalize;
 }
 
@@ -436,7 +438,7 @@ gth_extension_description_class_init (GthExtensionDescriptionClass *klass)
 static void
 gth_extension_description_init (GthExtensionDescription *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_EXTENSION_DESCRIPTION, GthExtensionDescriptionPrivate);
+	self->priv = gth_extension_description_get_instance_private (self);
 	self->priv->opened = FALSE;
 	self->priv->extension = NULL;
 }
@@ -470,7 +472,9 @@ gth_extension_description_load_from_file (GthExtensionDescription *desc,
 	basename = g_file_get_basename (file);
 	desc->id = _g_uri_remove_extension (basename);
 	desc->name = g_key_file_get_locale_string (key_file, "Extension", "Name", NULL, NULL);
-	desc->description = g_key_file_get_locale_string (key_file, "Extension", "Description", NULL, NULL);
+	desc->description = g_key_file_get_locale_string (key_file, "Extension", "Comment", NULL, NULL);
+	if (desc->description == NULL)
+		desc->description = g_key_file_get_locale_string (key_file, "Extension", "Description", NULL, NULL);
 	desc->version = g_key_file_get_locale_string (key_file, "Extension", "Version", NULL, NULL);
 	desc->authors = g_key_file_get_locale_string_list (key_file, "Extension", "Authors", NULL, NULL, NULL);
 	desc->copyright = g_key_file_get_locale_string (key_file, "Extension", "Copyright", NULL, NULL);
@@ -480,7 +484,6 @@ gth_extension_description_load_from_file (GthExtensionDescription *desc,
 	desc->mandatory = g_key_file_get_boolean (key_file, "Extension", "Mandatory", NULL);
 	desc->hidden = g_key_file_get_boolean (key_file, "Extension", "Hidden", NULL);
 	desc->loader_type = g_key_file_get_string (key_file, "Loader", "Type", NULL);
-	desc->loader_file = g_key_file_get_string (key_file, "Loader", "File", NULL);
 	desc->loader_requires = g_key_file_get_string_list (key_file, "Loader", "Requires", NULL, NULL);
 	desc->loader_after = g_key_file_get_string_list (key_file, "Loader", "After", NULL, NULL);
 
@@ -530,7 +533,10 @@ struct _GthExtensionManagerPrivate {
 };
 
 
-G_DEFINE_TYPE (GthExtensionManager, gth_extension_manager, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_CODE (GthExtensionManager,
+			 gth_extension_manager,
+			 G_TYPE_OBJECT,
+			 G_ADD_PRIVATE (GthExtensionManager))
 
 
 static void
@@ -550,7 +556,6 @@ gth_extension_manager_finalize (GObject *obj)
 static void
 gth_extension_manager_class_init (GthExtensionManagerClass *klass)
 {
-	g_type_class_add_private (klass, sizeof (GthExtensionManagerPrivate));
 	G_OBJECT_CLASS (klass)->finalize = gth_extension_manager_finalize;
 }
 
@@ -558,7 +563,7 @@ gth_extension_manager_class_init (GthExtensionManagerClass *klass)
 static void
 gth_extension_manager_init (GthExtensionManager *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_EXTENSION_MANAGER, GthExtensionManagerPrivate);
+	self->priv = gth_extension_manager_get_instance_private (self);
 	self->priv->extensions = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
 }
 
@@ -637,7 +642,7 @@ gth_extension_manager_new (void)
 {
 	GthExtensionManager *manager;
 
-	manager = (GthExtensionManager *) g_object_newv (GTH_TYPE_EXTENSION_MANAGER, 0, NULL);
+	manager = (GthExtensionManager *) g_object_new (GTH_TYPE_EXTENSION_MANAGER, NULL);
 	gth_extension_manager_load_extensions (manager);
 
 	return manager;
