@@ -55,8 +55,9 @@ static void gth_file_data_gth_duplicable_interface_init (GthDuplicableInterface
 G_DEFINE_TYPE_WITH_CODE (GthFileData,
 			 gth_file_data,
 			 G_TYPE_OBJECT,
+			 G_ADD_PRIVATE (GthFileData)
 			 G_IMPLEMENT_INTERFACE (GTH_TYPE_DUPLICABLE,
-					 	gth_file_data_gth_duplicable_interface_init))
+						gth_file_data_gth_duplicable_interface_init))
 
 
 static void
@@ -75,8 +76,6 @@ gth_file_data_finalize (GObject *obj)
 static void
 gth_file_data_class_init (GthFileDataClass *klass)
 {
-	g_type_class_add_private (klass, sizeof (GthFileDataPrivate));
-
 	G_OBJECT_CLASS (klass)->finalize = gth_file_data_finalize;
 }
 
@@ -98,7 +97,7 @@ gth_file_data_gth_duplicable_interface_init (GthDuplicableInterface *iface)
 static void
 gth_file_data_init (GthFileData *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_FILE_DATA, GthFileDataPrivate);
+	self->priv = gth_file_data_get_instance_private (self);
 	self->priv->dtime.tv_sec = 0;
 	self->priv->sort_key = NULL;
 	self->file = NULL;
@@ -535,7 +534,18 @@ gth_file_data_get_attribute_as_string (GthFileData *file_data,
 		if (GTH_IS_METADATA (obj)) {
 			switch (gth_metadata_get_data_type (GTH_METADATA (obj))) {
 			case GTH_METADATA_TYPE_STRING:
-				value = g_strdup (gth_metadata_get_formatted (GTH_METADATA (obj)));
+				if (strcmp (id, "general::rating") == 0) {
+					int n = atoi (gth_metadata_get_formatted (GTH_METADATA (obj)));
+					if ((n >= 0) && (n <= 5)) {
+						GString *str = g_string_new ("");
+						int      i;
+						for (i = 1; i <= n; i++)
+							g_string_append (str, "⭐");
+						value = g_string_free (str, FALSE);
+					}
+				}
+				if (value == NULL)
+					value = g_strdup (gth_metadata_get_formatted (GTH_METADATA (obj)));
 				break;
 			case GTH_METADATA_TYPE_STRING_LIST:
 				value = gth_string_list_join (GTH_STRING_LIST (gth_metadata_get_string_list (GTH_METADATA (obj))), " ");
