@@ -171,13 +171,6 @@ gth_main_register_default_hooks (void)
 	 **/
 	gth_hook_register ("gth-browser-view-file", 2);
 
-	/**
-	 * Called when the file list selection changes
-	 *
-	 * @browser (GthBrowser*): the relative window.
-	 **/
-	gth_hook_register ("gth-browser-selection-changed", 1);
-
 	/**
 	 * Called after a key press in the file list
 	 *
