@@ -61,7 +61,8 @@ G_BEGIN_DECLS
 #define PREF_BROWSER_THUMBNAIL_SIZE           "thumbnail-size"
 #define PREF_BROWSER_THUMBNAIL_LIMIT          "thumbnail-limit"
 #define PREF_BROWSER_THUMBNAIL_CAPTION        "thumbnail-caption"
-#define PREF_BROWSER_CLICK_POLICY             "click-policy"
+#define PREF_BROWSER_SINGLE_CLICK_ACTIVATION  "single-click-activation"
+#define PREF_BROWSER_OPEN_FILES_IN_FULLSCREEN "open-files-in-fullscreen"
 #define PREF_BROWSER_SORT_TYPE                "sort-type"
 #define PREF_BROWSER_SORT_INVERSE             "sort-inverse"
 #define PREF_BROWSER_WINDOW_WIDTH             "window-width"
@@ -69,16 +70,16 @@ G_BEGIN_DECLS
 #define PREF_BROWSER_WINDOW_MAXIMIZED         "maximized"
 #define PREF_BROWSER_STATUSBAR_VISIBLE        "statusbar-visible"
 #define PREF_BROWSER_SIDEBAR_VISIBLE          "sidebar-visible"
+#define PREF_BROWSER_SIDEBAR_SECTIONS         "sidebar-sections"
 #define PREF_BROWSER_PROPERTIES_VISIBLE       "properties-visible"
 #define PREF_BROWSER_PROPERTIES_ON_THE_RIGHT  "properties-on-the-right"
-#define PREF_BROWSER_PROPERTIES_DETAILS       "properties-details"
 #define PREF_BROWSER_THUMBNAIL_LIST_VISIBLE   "thumbnail-list-visible"
-#define PREF_BROWSER_THUMBNAIL_LIST_SIZE      "thumbnail-list-size"
 #define PREF_BROWSER_BROWSER_SIDEBAR_WIDTH    "browser-sidebar-width"
 #define PREF_BROWSER_VIEWER_SIDEBAR           "viewer-sidebar"
-#define PREF_BROWSER_VIEWER_SIDEBAR_WIDTH     "viewer-sidebar-width"
 #define PREF_BROWSER_VIEWER_THUMBNAILS_ORIENT "viewer-thumbnails-orientation"
 #define PREF_BROWSER_REUSE_ACTIVE_WINDOW      "reuse-active-window"
+#define PREF_FULLSCREEN_THUMBNAILS_VISIBLE    "fullscreen-thumbnails-visible"
+#define PREF_FULLSCREEN_SIDEBAR		      "fullscreen-sidebar"
 
 /* keys: add to catalog */
 
