@@ -50,8 +50,14 @@
 #define MAX_THUMBNAILER_LIFETIME  4000   /* kill the thumbnailer after this amount of time*/
 #define CHECK_CANCELLABLE_DELAY   200
 
-struct _GthThumbLoaderPrivate
-{
+
+enum {
+	READY,
+	LAST_SIGNAL
+};
+
+
+struct _GthThumbLoaderPrivate {
 	GthImageLoader   *iloader;
 	GthImageLoader   *tloader;
 	guint             use_cache : 1;
@@ -69,13 +75,10 @@ struct _GthThumbLoaderPrivate
 };
 
 
-enum {
-	READY,
-	LAST_SIGNAL
-};
-
-
-G_DEFINE_TYPE (GthThumbLoader, gth_thumb_loader, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_CODE (GthThumbLoader,
+			 gth_thumb_loader,
+			 G_TYPE_OBJECT,
+			 G_ADD_PRIVATE (GthThumbLoader))
 
 
 static void
@@ -96,8 +99,6 @@ gth_thumb_loader_class_init (GthThumbLoaderClass *class)
 {
 	GObjectClass *object_class;
 
-	g_type_class_add_private (class, sizeof (GthThumbLoaderPrivate));
-
 	object_class = G_OBJECT_CLASS (class);
 	object_class->finalize = gth_thumb_loader_finalize;
 }
@@ -106,10 +107,16 @@ gth_thumb_loader_class_init (GthThumbLoaderClass *class)
 static void
 gth_thumb_loader_init (GthThumbLoader *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_THUMB_LOADER, GthThumbLoaderPrivate);
+	self->priv = gth_thumb_loader_get_instance_private (self);
+	self->priv->iloader = NULL;
+	self->priv->tloader = NULL;
 	self->priv->use_cache = TRUE;
 	self->priv->save_thumbnails = TRUE;
+	self->priv->requested_size = 0;
+	self->priv->cache_max_size = 0;
 	self->priv->max_file_size = 0;
+	self->priv->thumb_size = GNOME_DESKTOP_THUMBNAIL_SIZE_NORMAL;
+	self->priv->thumb_factory = NULL;
 }
 
 
@@ -321,7 +328,7 @@ typedef struct {
 	GthThumbLoader     *thumb_loader;
 	GthFileData        *file_data;
 	int                 requested_size;
-	GSimpleAsyncResult *simple;
+	GTask              *task;
 	GCancellable       *cancellable;
 	char               *thumbnailer_tmpfile;
 	GPid                thumbnailer_pid;
@@ -351,7 +358,7 @@ load_data_unref (LoadData *load_data)
 {
 	g_object_unref (load_data->thumb_loader);
 	g_object_unref (load_data->file_data);
-	_g_object_unref (load_data->simple);
+	_g_object_unref (load_data->task);
 	_g_object_unref (load_data->cancellable);
 	g_free (load_data->thumbnailer_tmpfile);
 	g_free (load_data);
@@ -485,8 +492,7 @@ cache_image_ready_cb (GObject      *source_object,
 	load_result = g_new0 (LoadResult, 1);
 	load_result->file_data = g_object_ref (load_data->file_data);
 	load_result->image = surface;
-	g_simple_async_result_set_op_res_gpointer (load_data->simple, load_result, (GDestroyNotify) load_result_unref);
-	g_simple_async_result_complete_in_idle (load_data->simple);
+	g_task_return_pointer (load_data->task, load_result, (GDestroyNotify) load_result_unref);
 
 	load_data_unref (load_data);
 	g_object_unref (image);
@@ -619,8 +625,7 @@ original_image_loaded_correctly (GthThumbLoader *self,
 	load_result = g_new0 (LoadResult, 1);
 	load_result->file_data = g_object_ref (load_data->file_data);
 	load_result->image = cairo_surface_reference (local_image);
-	g_simple_async_result_set_op_res_gpointer (load_data->simple, load_result, (GDestroyNotify) load_result_unref);
-	g_simple_async_result_complete_in_idle (load_data->simple);
+	g_task_return_pointer (load_data->task, load_result, (GDestroyNotify) load_result_unref);
 
 	cairo_surface_destroy (local_image);
 }
@@ -630,19 +635,14 @@ static void
 failed_to_load_original_image (GthThumbLoader *self,
 			       LoadData       *load_data)
 {
-	char   *uri;
-	GError *error;
+	char *uri;
 
 	uri = g_file_get_uri (load_data->file_data->file);
 	gnome_desktop_thumbnail_factory_create_failed_thumbnail (self->priv->thumb_factory,
 								 uri,
 								 gth_file_data_get_mtime (load_data->file_data));
+	g_task_return_error (load_data->task, g_error_new_literal (GTH_ERROR, 0, "failed to generate the thumbnail"));
 
-	error = g_error_new_literal (GTH_ERROR, 0, "failed to generate the thumbnail");
-	g_simple_async_result_set_from_error (load_data->simple, error);
-	g_simple_async_result_complete_in_idle (load_data->simple);
-
-	g_error_free (error);
 	g_free (uri);
 }
 
@@ -708,19 +708,13 @@ watch_thumbnailer_cb (GPid     pid,
 	load_data->thumbnailer_watch = 0;
 
 	if (load_data->script_cancelled) {
-		GError *error;
-
 		if (load_data->thumbnailer_tmpfile != NULL) {
 			g_unlink (load_data->thumbnailer_tmpfile);
 			g_free (load_data->thumbnailer_tmpfile);
 			load_data->thumbnailer_tmpfile = NULL;
 		}
 
-		error = g_error_new_literal (G_IO_ERROR, G_IO_ERROR_CANCELLED, "script cancelled");
-		g_simple_async_result_set_from_error (load_data->simple, error);
-		g_simple_async_result_complete_in_idle (load_data->simple);
-
-		g_error_free (error);
+		g_task_return_error (load_data->task, g_error_new_literal (G_IO_ERROR, G_IO_ERROR_CANCELLED, "script cancelled"));
 
 		return;
 	}
@@ -771,8 +765,7 @@ original_image_ready_cb (GObject      *source_object,
 		char *uri;
 
 		if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-			g_simple_async_result_set_from_error (load_data->simple, error);
-			g_simple_async_result_complete_in_idle (load_data->simple);
+			g_task_return_error (load_data->task, error);
 			return;
 		}
 
@@ -827,15 +820,12 @@ gth_thumb_loader_load (GthThumbLoader      *self,
 		       GAsyncReadyCallback  callback,
 		       gpointer             user_data)
 {
-	GSimpleAsyncResult *simple;
-	char               *cache_path;
-	char               *uri;
-	LoadData           *load_data;
+	GTask    *task;
+	char     *cache_path;
+	char     *uri;
+	LoadData *load_data;
 
-	simple = g_simple_async_result_new (G_OBJECT (self),
-					    callback,
-					    user_data,
-					    gth_thumb_loader_load);
+	task = g_task_new (G_OBJECT (self), cancellable, callback, user_data);
 
 	cache_path = NULL;
 
@@ -850,15 +840,10 @@ gth_thumb_loader_load (GthThumbLoader      *self,
 		mtime = gth_file_data_get_mtime (file_data);
 
 		if (gnome_desktop_thumbnail_factory_has_valid_failed_thumbnail (self->priv->thumb_factory, uri, mtime)) {
-			GError *error;
+			g_task_return_error (task, g_error_new_literal (GTH_ERROR, 0, "found a failed thumbnail"));
 
-			error = g_error_new_literal (GTH_ERROR, 0, "found a failed thumbnail");
-			g_simple_async_result_set_from_error (simple, error);
-			g_simple_async_result_complete_in_idle (simple);
-
-			g_error_free (error);
 			g_free (uri);
-			g_object_unref (simple);
+			g_object_unref (task);
 
 			return;
 		}
@@ -872,22 +857,15 @@ gth_thumb_loader_load (GthThumbLoader      *self,
 	    && (self->priv->max_file_size > 0)
 	    && (g_file_info_get_size (file_data->info) > self->priv->max_file_size))
 	{
-		GError *error;
-
-		error = g_error_new_literal (GTH_ERROR, 0, "file too big to generate the thumbnail");
-		g_simple_async_result_set_from_error (simple, error);
-		g_simple_async_result_complete_in_idle (simple);
-
-		g_error_free (error);
-		g_object_unref (simple);
-
+		g_task_return_error (task, g_error_new_literal (GTH_ERROR, 0, "file too big to generate the thumbnail"));
+		g_object_unref (task);
 		return;
 	}
 
 	load_data = load_data_new (file_data, self->priv->requested_size);
 	load_data->thumb_loader = g_object_ref (self);
 	load_data->cancellable = _g_object_ref (cancellable);
-	load_data->simple = simple;
+	load_data->task = task;
 
 	if (cache_path != NULL) {
 		GFile       *cache_file;
@@ -925,19 +903,17 @@ gth_thumb_loader_load_finish (GthThumbLoader   *self,
 			      cairo_surface_t **image,
 			      GError          **error)
 {
-	GSimpleAsyncResult *simple;
-	LoadResult         *load_result;
+	LoadResult *load_result;
 
-	g_return_val_if_fail (g_simple_async_result_is_valid (result, G_OBJECT (self), gth_thumb_loader_load), FALSE);
+	g_return_val_if_fail (g_task_is_valid (G_TASK (result), G_OBJECT (self)), FALSE);
 
-	simple = G_SIMPLE_ASYNC_RESULT (result);
-
-	if (g_simple_async_result_propagate_error (simple, error))
+	load_result = g_task_propagate_pointer (G_TASK (result), error);
+	if (load_result == NULL)
 		return FALSE;
 
-	load_result = g_simple_async_result_get_op_res_gpointer (simple);
 	if (image != NULL)
 		*image = cairo_surface_reference (load_result->image);
+	load_result_unref (load_result);
 
 	return TRUE;
 }
