@@ -108,14 +108,18 @@ void            _gtk_combo_box_append_texts                (GtkComboBoxText  *co
 					    	    	    const char       *first_text,
 					    	    	    ...);
 GtkWidget *     _gtk_image_new_from_xpm_data               (char             *xpm_data[]);
-GtkWidget *     _gtk_image_new_from_inline                 (const guint8     *data);
-void            _gtk_widget_get_screen_size                (GtkWidget        *widget,
+gboolean        _gtk_widget_get_screen_size                (GtkWidget        *widget,
 					    	    	    int              *width,
 					    	    	    int              *height);
 int             _gtk_widget_get_allocated_width            (GtkWidget        *widget);
 int             _gtk_widget_get_allocated_height           (GtkWidget        *widget);
 int             _gtk_widget_lookup_for_size                (GtkWidget        *widget,
 							    GtkIconSize       icon_size);
+void            _gtk_widget_set_margin                     (GtkWidget        *widget,
+							    int               top,
+							    int               right,
+							    int               bottom,
+							    int               left);
 void            _gtk_tree_path_list_free                   (GList            *list);
 int             _gtk_paned_get_position2                   (GtkPaned         *paned);
 void            _g_launch_command                          (GtkWidget        *parent,
@@ -126,8 +130,7 @@ void            _gtk_window_resize_to_fit_screen_height    (GtkWidget        *wi
 					    	    	    int               default_width);
 void            _gtk_info_bar_clear_action_area            (GtkInfoBar       *info_bar);
 GdkDragAction   _gtk_menu_ask_drag_drop_action             (GtkWidget        *widget,
-					      	      	    GdkDragAction     actions,
-					      	      	    guint32           activate_time);
+					      	      	    GdkDragAction     actions);
 gboolean        _gdk_rgba_darker                           (GdkRGBA          *color,
 		 					    GdkRGBA          *result);
 gboolean        _gdk_rgba_lighter                          (GdkRGBA          *color,
@@ -152,10 +155,17 @@ void		_gtk_window_add_accelerators_from_menu	   (GtkWindow		*window,
 gboolean	_gtk_window_get_is_maximized 		   (GtkWindow		*window);
 gboolean        _gtk_window_get_monitor_info               (GtkWindow		*window,
 							    GdkRectangle        *geometry,
-							    int                 *number);
+							    int                 *number,
+							    char               **name);
+gboolean        _gtk_widget_get_monitor_geometry           (GtkWidget           *widget,
+							    GdkRectangle        *geometry);
 GdkDevice *     _gtk_widget_get_client_pointer		   (GtkWidget		*widget);
 void            _gtk_list_box_add_separator		   (GtkListBox		*list_box);
 gboolean        _gtk_settings_get_dialogs_use_header       (void);
+GdkCursor *     _gdk_cursor_new_for_widget                 (GtkWidget           *widget,
+							    GdkCursorType        cursor_type);
+void		_gtk_widget_reparent			   (GtkWidget		*widget,
+							    GtkWidget		*new_parent);
 
 G_END_DECLS
 
